@@ -56,24 +56,25 @@ class heatMap:
 
 		return H_sorted_kernel
 
-	def draw_HeatMap(self, kernel, xTicklabel=[], yTicklabel=[], title='', 
-						xlabel='Features', ylabel='Samples', ticker_rotate=0, ticker_fontsize=9,
+	def draw_HeatMap(self, kernel, title='', 
+						xlabel='Features', ylabel='Samples', ticker_fontsize=9,
 						fsize=14, use_seaborn=False, vmin=0, vmax=1, 
-						center=None, linewidths=0, cmap=None, path='', subplot=None):
+						center=None, linewidths=0, cmap=None, path='', subplot=None,
+						xticker_rotate=0, yticker_rotate=0,
+						xtick_locations=None, xtick_labels=None, ytick_locations=None, ytick_labels=None):
 
 		if use_seaborn:
 			ax = sns.heatmap(kernel, vmin=vmin, vmax=vmax, center=center, linewidths=linewidths, cmap=cmap)
 			plt.title(title, fontsize=fsize)
-			plt.xticks(fontsize=ticker_fontsize, rotation=ticker_rotate)
-			plt.yticks(fontsize=ticker_fontsize, rotation=ticker_rotate)
+			plt.xticks(fontsize=ticker_fontsize, rotation=xticker_rotate)
+			plt.yticks(fontsize=ticker_fontsize, rotation=yticker_rotate)
 		
 			plt.tight_layout()
 			plt.show() 
 		else:
-			yTicklabel = list(reversed(yTicklabel))
 			
 			kernel = np.flipud(kernel)
-			fig, ax = plt.subplots()
+			#fig, ax = plt.subplots()
 			#plt.subplots(2,1)
 			#if subplot is None: fig, ax = plt.subplots()
 			#else: fig, ax = plt.subplots(subplot)
@@ -81,18 +82,22 @@ class heatMap:
 
 			heatmap = plt.pcolor(kernel, cmap=matplotlib.cm.Blues, alpha=0.8)
 
-			if len(yTicklabel) > 0:
-				ax.set_yticks(np.arange(kernel.shape[0]) + 0.5, minor=False)
-				ax.set_yticklabels(yTicklabel, rotation='horizontal', minor=False, size=fsize)
+			#yTicklabel = list(reversed(yTicklabel))
+			#if len(yTicklabel) > 0:
+			#	ax.set_yticks(np.arange(kernel.shape[0]) + 0.5, minor=False)
+			#	ax.set_yticklabels(yTicklabel, rotation='horizontal', minor=False, size=fsize)
 			
-			if len(xTicklabel) > 0:
-				ax.set_xticks(np.arange(kernel.shape[1]) + 0.5, minor=False)
-				ax.set_xticklabels(xTicklabel, rotation='vertical', minor=False, size=fsize)
+			#if len(xTicklabel) > 0:
+			#	ax.set_xticks(np.arange(kernel.shape[1]) + 0.5, minor=False)
+			#	ax.set_xticklabels(xTicklabel, rotation='vertical', minor=False, size=fsize)
 		 
 			plt.title(title, fontsize=fsize)
-			ax.tick_params(axis='both', which='major', labelsize=ticker_fontsize)
-			ax.tick_params(axis='both', which='minor', labelsize=ticker_fontsize)
-			plt.xticks(fontsize=ticker_fontsize, rotation=ticker_rotate)
+			plt.xticks(ticks=xtick_locations, labels=xtick_labels, fontsize=ticker_fontsize, rotation=xticker_rotate)
+			plt.yticks(fontsize=ticker_fontsize, rotation=yticker_rotate, ticks=ytick_locations, labels=ytick_labels )
+
+			#ax.tick_params(axis='both', which='major', labelsize=ticker_fontsize)
+			#ax.tick_params(axis='both', which='minor', labelsize=ticker_fontsize)
+			#plt.xticks(fontsize=ticker_fontsize, rotation=ticker_rotate)
 			#plt.yticks(fontsize=ticker_fontsize, rotation=ticker_rotate)
 
 			if xlabel != '': plt.xlabel(xlabel, fontsize=fsize)
